@@ -15,10 +15,11 @@ describe 'nova::compute::libvirt::qemu' do
         :changes => [
             "rm max_files",
             "rm max_processes",
-            "rm group",
             "rm vnc_tls",
             "rm vnc_tls_x509_verify",
             "rm default_tls_x509_verify",
+            "rm user",
+            "rm group",
             "rm memory_backing_dir",
             "rm nbd_tls",
         ],
@@ -39,6 +40,9 @@ describe 'nova::compute::libvirt::qemu' do
             "set vnc_tls 0",
             "set vnc_tls_x509_verify 0",
             "set default_tls_x509_verify 1",
+            "rm user",
+            "rm group",
+            "rm memory_backing_dir",
             "set nbd_tls 0",
         ],
         :tag     => 'qemu-conf-augeas',
@@ -61,17 +65,21 @@ describe 'nova::compute::libvirt::qemu' do
             "set vnc_tls 0",
             "set vnc_tls_x509_verify 0",
             "set default_tls_x509_verify 1",
+            "rm user",
+            "rm group",
+            "rm memory_backing_dir",
             "set nbd_tls 0",
         ],
         :tag     => 'qemu-conf-augeas',
       }) }
     end
 
-    context 'when configuring qemu with group parameter' do
+    context 'when configuring qemu with user/group parameter' do
       let :params do
         {
           :configure_qemu     => true,
-          :group              => 'openvswitch',
+          :user               => 'qemu-user',
+          :group              => 'qemu-group',
           :max_files          => 32768,
           :max_processes      => 131072,
           :memory_backing_dir => '/tmp',
@@ -85,7 +93,8 @@ describe 'nova::compute::libvirt::qemu' do
             "set vnc_tls 0",
             "set vnc_tls_x509_verify 0",
             "set default_tls_x509_verify 1",
-            "set group openvswitch",
+            "set user qemu-user",
+            "set group qemu-group",
             "set memory_backing_dir /tmp",
             "set nbd_tls 0",
         ],
@@ -108,6 +117,9 @@ describe 'nova::compute::libvirt::qemu' do
             "set vnc_tls 1",
             "set vnc_tls_x509_verify 1",
             "set default_tls_x509_verify 1",
+            "rm user",
+            "rm group",
+            "rm memory_backing_dir",
             "set nbd_tls 0",
         ],
         :tag     => 'qemu-conf-augeas',
@@ -129,6 +141,9 @@ describe 'nova::compute::libvirt::qemu' do
             "set vnc_tls 0",
             "set vnc_tls_x509_verify 0",
             "set default_tls_x509_verify 1",
+            "rm user",
+            "rm group",
+            "rm memory_backing_dir",
             "set nbd_tls 0",
         ],
         :tag     => 'qemu-conf-augeas',
@@ -151,6 +166,9 @@ describe 'nova::compute::libvirt::qemu' do
             "set vnc_tls 1",
             "set vnc_tls_x509_verify 0",
             "set default_tls_x509_verify 1",
+            "rm user",
+            "rm group",
+            "rm memory_backing_dir",
             "set nbd_tls 0",
         ],
         :tag     => 'qemu-conf-augeas',
@@ -172,6 +190,9 @@ describe 'nova::compute::libvirt::qemu' do
             "set vnc_tls 0",
             "set vnc_tls_x509_verify 0",
             "set default_tls_x509_verify 0",
+            "rm user",
+            "rm group",
+            "rm memory_backing_dir",
             "set nbd_tls 0",
         ],
         :tag     => 'qemu-conf-augeas',
@@ -193,6 +214,9 @@ describe 'nova::compute::libvirt::qemu' do
             "set vnc_tls 0",
             "set vnc_tls_x509_verify 0",
             "set default_tls_x509_verify 1",
+            "rm user",
+            "rm group",
+            "rm memory_backing_dir",
             "set nbd_tls 1",
         ],
         :tag     => 'qemu-conf-augeas',
