@@ -33,14 +33,15 @@ describe 'nova::migration::libvirt' do
   shared_examples_for 'nova migration with libvirt' do
 
     context 'with default params' do
-      it { is_expected.to contain_libvirtd_config('listen_tls').with_value('0') }
-      it { is_expected.to contain_libvirtd_config('listen_tcp').with_value('1') }
       it { is_expected.to contain_libvirtd_config('auth_tls').with_value('<SERVICE DEFAULT>').with_quote(true) }
       it { is_expected.to contain_libvirtd_config('auth_tcp').with_value('none').with_quote(true) }
       it { is_expected.to contain_libvirtd_config('ca_file').with_value('<SERVICE DEFAULT>').with_quote(true) }
       it { is_expected.to contain_libvirtd_config('crl_file').with_value('<SERVICE DEFAULT>').with_quote(true) }
       it { is_expected.to contain_nova_config('libvirt/live_migration_tunnelled').with_value('<SERVICE DEFAULT>') }
       it { is_expected.to contain_nova_config('libvirt/live_migration_with_native_tls').with_value('<SERVICE DEFAULT>') }
+      it { is_expected.to contain_nova_config('libvirt/live_migration_downtime').with_value('<SERVICE DEFAULT>') }
+      it { is_expected.to contain_nova_config('libvirt/live_migration_downtime_steps').with_value('<SERVICE DEFAULT>') }
+      it { is_expected.to contain_nova_config('libvirt/live_migration_downtime_delay').with_value('<SERVICE DEFAULT>') }
       it { is_expected.to contain_nova_config('libvirt/live_migration_completion_timeout').with_value('<SERVICE DEFAULT>') }
       it { is_expected.to contain_nova_config('libvirt/live_migration_timeout_action').with_value('<SERVICE DEFAULT>') }
       it { is_expected.to contain_nova_config('libvirt/live_migration_uri').with_value('qemu+tcp://%s/system') }
@@ -52,8 +53,6 @@ describe 'nova::migration::libvirt' do
     context 'with modular_libvirt set to true' do
       let(:params) { { :modular_libvirt => true} }
 
-      it { is_expected.to contain_virtproxyd_config('listen_tls').with_value('0') }
-      it { is_expected.to contain_virtproxyd_config('listen_tcp').with_value('1') }
       it { is_expected.to contain_virtproxyd_config('auth_tls').with_value('<SERVICE DEFAULT>').with_quote(true) }
       it { is_expected.to contain_virtproxyd_config('auth_tcp').with_value('none').with_quote(true) }
       it { is_expected.to contain_virtproxyd_config('ca_file').with_value('<SERVICE DEFAULT>').with_quote(true) }
@@ -109,8 +108,6 @@ describe 'nova::migration::libvirt' do
           :transport => 'tls',
         }
       end
-      it { is_expected.to contain_libvirtd_config('listen_tls').with_value('1') }
-      it { is_expected.to contain_libvirtd_config('listen_tcp').with_value('0') }
       it { is_expected.to contain_libvirtd_config('auth_tls').with_value('none').with_quote(true) }
       it { is_expected.to contain_libvirtd_config('auth_tcp').with_value('<SERVICE DEFAULT>').with_quote(true) }
       it { is_expected.to contain_libvirtd_config('ca_file').with_value('<SERVICE DEFAULT>').with_quote(true) }
@@ -125,8 +122,6 @@ describe 'nova::migration::libvirt' do
           :modular_libvirt => true,
         }
       end
-      it { is_expected.to contain_virtproxyd_config('listen_tls').with_value('1') }
-      it { is_expected.to contain_virtproxyd_config('listen_tcp').with_value('0') }
       it { is_expected.to contain_virtproxyd_config('auth_tls').with_value('none').with_quote(true) }
       it { is_expected.to contain_virtproxyd_config('auth_tcp').with_value('<SERVICE DEFAULT>').with_quote(true) }
       it { is_expected.to contain_virtproxyd_config('ca_file').with_value('<SERVICE DEFAULT>').with_quote(true) }
@@ -142,8 +137,6 @@ describe 'nova::migration::libvirt' do
           :live_migration_inbound_addr => 'host1.example.com',
         }
       end
-      it { is_expected.to contain_libvirtd_config('listen_tls').with_value('1') }
-      it { is_expected.to contain_libvirtd_config('listen_tcp').with_value('0') }
       it { is_expected.to contain_libvirtd_config('auth_tls').with_value('none').with_quote(true) }
       it { is_expected.to contain_libvirtd_config('auth_tcp').with_value('<SERVICE DEFAULT>').with_quote(true) }
       it { is_expected.to contain_libvirtd_config('ca_file').with_value('<SERVICE DEFAULT>').with_quote(true) }
@@ -165,11 +158,17 @@ describe 'nova::migration::libvirt' do
       let :params do
         {
           :live_migration_tunnelled          => true,
+          :live_migration_downtime           => 800,
+          :live_migration_downtime_steps     => 15,
+          :live_migration_downtime_delay     => 5,
           :live_migration_completion_timeout => '1500',
           :live_migration_timeout_action     => 'force_complete',
         }
       end
       it { is_expected.to contain_nova_config('libvirt/live_migration_tunnelled').with(:value => true) }
+      it { is_expected.to contain_nova_config('libvirt/live_migration_downtime').with_value(800) }
+      it { is_expected.to contain_nova_config('libvirt/live_migration_downtime_steps').with_value(15) }
+      it { is_expected.to contain_nova_config('libvirt/live_migration_downtime_delay').with_value(5) }
       it { is_expected.to contain_nova_config('libvirt/live_migration_completion_timeout').with_value('1500') }
       it { is_expected.to contain_nova_config('libvirt/live_migration_timeout_action').with_value('force_complete') }
     end
@@ -284,8 +283,10 @@ describe 'nova::migration::libvirt' do
           :configure_libvirt => false
         }
       end
-      it { is_expected.not_to contain_libvirtd_config('listen_tls') }
-      it { is_expected.not_to contain_libvirtd_config('listen_tcp') }
+      it { is_expected.to_not contain_libvirtd_config('auth_tls') }
+      it { is_expected.to_not contain_libvirtd_config('auth_tcp') }
+      it { is_expected.to_not contain_libvirtd_config('ca_file') }
+      it { is_expected.to_not contain_libvirtd_config('crl_file') }
     end
 
     context 'when not configuring nova and tls enabled' do
@@ -298,25 +299,6 @@ describe 'nova::migration::libvirt' do
       it { is_expected.not_to contain_nova_config('libvirt/live_migration_uri').with_value('qemu+tls://%s/system') }
     end
 
-    context 'with listen_address set' do
-      let :params do
-        {
-          :listen_address => "127.0.0.1"
-        }
-      end
-      it { is_expected.to contain_libvirtd_config('listen_addr').with_value('127.0.0.1').with_quote(true) }
-    end
-
-    context 'with listen_address set and modular_libvirt set to true' do
-      let :params do
-        {
-          :listen_address => "127.0.0.1",
-          :modular_libvirt => true,
-        }
-      end
-      it { is_expected.to contain_virtproxyd_config('listen_addr').with_value('127.0.0.1').with_quote(true) }
-    end
-
     context 'with ssh transport' do
       let :params do
         {
@@ -324,8 +306,6 @@ describe 'nova::migration::libvirt' do
         }
       end
       it { is_expected.to contain_nova_config('libvirt/live_migration_uri').with_value('qemu+ssh://%s/system')}
-      it { is_expected.to contain_libvirtd_config('listen_tls').with_value('0') }
-      it { is_expected.to contain_libvirtd_config('listen_tcp').with_value('0') }
     end
 
     context 'with ssh transport and modular_libvirt set to true' do
@@ -336,8 +316,6 @@ describe 'nova::migration::libvirt' do
         }
       end
       it { is_expected.to contain_nova_config('libvirt/live_migration_uri').with_value('qemu+ssh://%s/system')}
-      it { is_expected.to contain_virtproxyd_config('listen_tls').with_value('0') }
-      it { is_expected.to contain_virtproxyd_config('listen_tcp').with_value('0') }
     end
 
     context 'with ssh transport with user' do
@@ -348,8 +326,6 @@ describe 'nova::migration::libvirt' do
         }
       end
       it { is_expected.to contain_nova_config('libvirt/live_migration_uri').with_value('qemu+ssh://foobar@%s/system')}
-      it { is_expected.to contain_libvirtd_config('listen_tls').with_value('0') }
-      it { is_expected.to contain_libvirtd_config('listen_tcp').with_value('0') }
     end
 
     context 'with ssh transport with user and modular_libvirt set to true' do
@@ -361,8 +337,6 @@ describe 'nova::migration::libvirt' do
         }
       end
       it { is_expected.to contain_nova_config('libvirt/live_migration_uri').with_value('qemu+ssh://foobar@%s/system')}
-      it { is_expected.to contain_virtproxyd_config('listen_tls').with_value('0') }
-      it { is_expected.to contain_virtproxyd_config('listen_tcp').with_value('0') }
     end
 
     context 'with ssh transport with port' do
@@ -373,8 +347,6 @@ describe 'nova::migration::libvirt' do
         }
       end
       it { is_expected.to contain_nova_config('libvirt/live_migration_uri').with_value('qemu+ssh://%s:1234/system')}
-      it { is_expected.to contain_libvirtd_config('listen_tls').with_value('0') }
-      it { is_expected.to contain_libvirtd_config('listen_tcp').with_value('0') }
     end
 
     context 'with ssh transport with port and modular_libvirt set to true' do
@@ -386,8 +358,6 @@ describe 'nova::migration::libvirt' do
         }
       end
       it { is_expected.to contain_nova_config('libvirt/live_migration_uri').with_value('qemu+ssh://%s:1234/system')}
-      it { is_expected.to contain_virtproxyd_config('listen_tls').with_value('0') }
-      it { is_expected.to contain_virtproxyd_config('listen_tcp').with_value('0') }
     end
 
     context 'with ssh transport with extraparams' do
@@ -398,8 +368,6 @@ describe 'nova::migration::libvirt' do
         }
       end
       it { is_expected.to contain_nova_config('libvirt/live_migration_uri').with_value('qemu+ssh://%s/system?foo=%%25&bar=baz')}
-      it { is_expected.to contain_libvirtd_config('listen_tls').with_value('0') }
-      it { is_expected.to contain_libvirtd_config('listen_tcp').with_value('0') }
     end
 
     context 'with ssh transport with extraparams and modular_libvirt set to true' do
@@ -411,8 +379,6 @@ describe 'nova::migration::libvirt' do
         }
       end
       it { is_expected.to contain_nova_config('libvirt/live_migration_uri').with_value('qemu+ssh://%s/system?foo=%%25&bar=baz')}
-      it { is_expected.to contain_virtproxyd_config('listen_tls').with_value('0') }
-      it { is_expected.to contain_virtproxyd_config('listen_tcp').with_value('0') }
     end
 
   end
@@ -424,16 +390,19 @@ describe 'nova::migration::libvirt' do
       end
 
       it { is_expected.to contain_file_line('/etc/default/libvirtd libvirtd opts').with(
-        :path  => '/etc/default/libvirtd',
-        :line  => 'libvirtd_opts=',
-        :match => 'libvirtd_opts=',
-        :tag   => 'libvirt-file_line',
+        :ensure            => 'absent',
+        :path              => '/etc/default/libvirtd',
+        :match             => '^libvirtd_opts=$',
+        :match_for_absence => true,
       ) }
       it { is_expected.to contain_service('libvirtd-tls').with(
         :name   => 'libvirtd-tls.socket',
         :ensure => 'running',
         :enable => true,
-        )}
+      )}
+      it { is_expected.to contain_file('/etc/systemd/system/libvirtd-tls.socket').with(
+        :ensure => 'absent',
+      )}
     end
 
     context 'with tcp transport' do
@@ -442,16 +411,55 @@ describe 'nova::migration::libvirt' do
       end
 
       it { is_expected.to contain_file_line('/etc/default/libvirtd libvirtd opts').with(
-        :path  => '/etc/default/libvirtd',
-        :line  => 'libvirtd_opts=',
-        :match => 'libvirtd_opts=',
-        :tag   => 'libvirt-file_line',
+        :ensure            => 'absent',
+        :path              => '/etc/default/libvirtd',
+        :match             => '^libvirtd_opts=$',
+        :match_for_absence => true,
       ) }
       it { is_expected.to contain_service('libvirtd-tcp').with(
         :name   => 'libvirtd-tcp.socket',
         :ensure => 'running',
         :enable => true,
-        )}
+      )}
+      it { is_expected.to contain_file('/etc/systemd/system/libvirtd-tcp.socket').with(
+        :ensure => 'absent',
+      )}
+    end
+
+    context 'with tls transport and modular daemons' do
+      let :params do
+        {
+          :transport       => 'tls',
+          :modular_libvirt => true,
+        }
+      end
+
+      it { is_expected.to contain_service('virtproxyd-tls').with(
+        :name   => 'virtproxyd-tls.socket',
+        :ensure => 'running',
+        :enable => true,
+      )}
+      it { is_expected.to contain_file('/etc/systemd/system/virtproxyd-tls.socket').with(
+        :ensure => 'absent',
+      )}
+    end
+
+    context 'with tcp transport and modular daemons' do
+      let :params do
+        {
+          :transport       => 'tcp',
+          :modular_libvirt => true,
+        }
+      end
+
+      it { is_expected.to contain_service('virtproxyd-tcp').with(
+        :name   => 'virtproxyd-tcp.socket',
+        :ensure => 'running',
+        :enable => true,
+      )}
+      it { is_expected.to contain_file('/etc/systemd/system/virtproxyd-tcp.socket').with(
+        :ensure => 'absent',
+      )}
     end
   end
 
@@ -462,44 +470,82 @@ describe 'nova::migration::libvirt' do
       end
 
       it { is_expected.to contain_file('/etc/sysconfig/libvirtd').with(
-        :ensure => 'present',
+        :ensure => 'absent',
         :path   => '/etc/sysconfig/libvirtd',
         :tag    => 'libvirt-file',
       )}
-      it { is_expected.to contain_file_line('/etc/sysconfig/libvirtd libvirtd args').with(
-        :path  => '/etc/sysconfig/libvirtd',
-        :line  => 'LIBVIRTD_ARGS=',
-        :match => '^LIBVIRTD_ARGS=',
-        :tag   => 'libvirt-file_line',
-      )}
       it { is_expected.to contain_service('libvirtd-tls').with(
         :name   => 'libvirtd-tls.socket',
         :ensure => 'running',
         :enable => true,
       )}
+      it { is_expected.to contain_file('/etc/systemd/system/libvirtd-tls.socket').with(
+        :ensure => 'absent',
+      )}
     end
 
     context 'with tcp transport' do
       let :params do
-        { :transport => 'tcp' }
+        {
+          :transport      => 'tcp',
+          :listen_address => '127.0.0.1'
+        }
       end
 
       it { is_expected.to contain_file('/etc/sysconfig/libvirtd').with(
-        :ensure => 'present',
+        :ensure => 'absent',
         :path   => '/etc/sysconfig/libvirtd',
         :tag    => 'libvirt-file',
       )}
-      it { is_expected.to contain_file_line('/etc/sysconfig/libvirtd libvirtd args').with(
-        :path  => '/etc/sysconfig/libvirtd',
-        :line  => 'LIBVIRTD_ARGS=',
-        :match => '^LIBVIRTD_ARGS=',
-        :tag   => 'libvirt-file_line',
-      )}
       it { is_expected.to contain_service('libvirtd-tcp').with(
         :name   => 'libvirtd-tcp.socket',
         :ensure => 'running',
         :enable => true,
       )}
+      it { is_expected.to contain_file_line('libvirtd-tcp.socket ListenStream').with(
+        :path  => '/etc/systemd/system/libvirtd-tcp.socket',
+        :line  => 'ListenStream=127.0.0.1:16509',
+        :match => '^ListenStream=.*',
+      )}
+    end
+
+    context 'with tls transport and modular daemons' do
+      let :params do
+        {
+          :transport       => 'tls',
+          :modular_libvirt => true,
+          :listen_address  => '::1'
+        }
+      end
+
+      it { is_expected.to contain_service('virtproxyd-tls').with(
+        :name   => 'virtproxyd-tls.socket',
+        :ensure => 'running',
+        :enable => true,
+      )}
+      it { is_expected.to contain_file_line('virtproxyd-tls.socket ListenStream').with(
+        :path  => '/etc/systemd/system/virtproxyd-tls.socket',
+        :line  => 'ListenStream=[::1]:16514',
+        :match => '^ListenStream=.*',
+      )}
+    end
+
+    context 'with tcp transport and modular daemons' do
+      let :params do
+        {
+          :transport       => 'tcp',
+          :modular_libvirt => true,
+        }
+      end
+
+      it { is_expected.to contain_service('virtproxyd-tcp').with(
+        :name   => 'virtproxyd-tcp.socket',
+        :ensure => 'running',
+        :enable => true,
+      )}
+      it { is_expected.to contain_file('/etc/systemd/system/virtproxyd-tcp.socket').with(
+        :ensure => 'absent',
+      )}
     end
   end
 
@@ -508,11 +554,11 @@ describe 'nova::migration::libvirt' do
   }).each do |os,facts|
     context "on #{os}" do
       let (:facts) do
-        facts.merge!(OSDefaults.get_facts({ :os_workers => 5 }))
+        facts.merge!(OSDefaults.get_facts())
       end
 
       it_behaves_like 'nova migration with libvirt'
-      case facts[:osfamily]
+      case facts[:os]['family']
       when 'Debian'
         it_behaves_like 'nova migration with libvirt in Debian'
       when 'RedHat'
